@@ -1,5 +1,6 @@
 import os
 import json
+from nn_trainer.logger import Logger
 
 import numpy
 from nn_trainer.trainers import *
@@ -17,6 +18,11 @@ from torch.autograd import grad as torch_grad
 
 from typing import Dict
 
+def make_path(output_path):
+    if not os.path.isdir(output_path):
+        os.makedirs(output_path)
+    return output_path
+
 class WassersteinGanNnTrainer(AbstractNnTrainer):
     """
     Basic implementation of a generative adversarial network trainer using Wasserstein loss metric
@@ -27,7 +33,6 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
     """
     def __init__(
         self,
-        args,
         generator_neural_network: torch.nn.Module, 
         discriminator_neural_network: torch.nn.Module, 
         generator_optimizer_fn: Any = torch.optim.Adam,
@@ -41,12 +46,14 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         patience: int = 0,
         critic_iterations: int = 5,
         gradient_penalty_weight: int = 10,
-        logger: Any = None
+        max_epoch_count:int = 200,
+        batch_size:int = 32,
+        output_dir:str = os.path.join(os.getcwd(), "output"),
+        logger:Logger = None
         ):
         """Constructor
 
         Args:
-            args (Any): Command line args
             generator_neural_network (torch.nn.Module): [description]
             discriminator_neural_network (torch.nn.Module): [description]
             generator_optimizer_fn (Any, optional): [description]. Defaults to torch.optim.Adam.
@@ -58,10 +65,9 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
             dtype (Any, optional): [description]. Defaults to torch.float32.
             verbose (bool, optional): [description]. Defaults to False.
             patience (int, optional): [description]. Defaults to 0.
-            logger (Any, optional): [description]. Defaults to None.
+            logger (Logger, optional): [description]. Defaults to None.
         """
         super().__init__(
-            args,
             generator_neural_network, 
             generator_optimizer_fn,
             generator_optimizer_params,
@@ -70,6 +76,9 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
             dtype,
             verbose,
             patience,
+            max_epoch_count,
+            batch_size,
+            output_dir,
             logger)
         self._critic_iterations = critic_iterations
         self._net_d = discriminator_neural_network.type(dtype)
@@ -115,7 +124,7 @@ class WassersteinGanNnTrainer(AbstractNnTrainer):
         
         self._eval_names = ['validation']
 
-        with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
+        #with open(os.path.join(self._model_directory_path, 'training_config.json'), 'w') as f: json.dump(self._args, f, indent=4)
 
         self._stop_training = False
         
